==> sugarcrm-2.5.1b_1.tbz: www/sugarcrm/modules/Meetings/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Id: en_us.lang.php,v 1.31 2005/02/09 07:08:55 andrew Exp $
 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Meetings',
  'LBL_MODULE_TITLE' => 'Meetings: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Meeting Search',
  'LBL_LIST_FORM_TITLE' => 'Meeting List',
  'LBL_NEW_FORM_TITLE' => 'Schedule Meeting',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact Name',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_DATE' => 'Start Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_SUBJECT' => 'Subject: ',
  'LBL_STATUS' => 'Status:',
  'LBL_LOCATION' => 'Location:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_DATE' => 'Start Date:',
  'LBL_TIME' => 'Start Time:',
  'LBL_DURATION' => 'Duration:',
  'LBL_DURATION_HOURS' => 'Duration Hours:',
  'LBL_DURATION_MINUTES' => 'Duration Minutes:',
  'LBL_HOURS_MINS' => '(hours/minutes)',
  'LBL_CONTACT_NAME' => 'Contact Name: ',
  'LBL_MEETING' => 'Meeting:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_COLON' => ':',
  'LBL_DEFAULT_STATUS' => 'Planned',
'LNK_NEW_CALL'=>'Schedule Call',
'LNK_NEW_MEETING'=>'Schedule Meeting',
'LNK_NEW_TASK'=>'Create Task',
'LNK_NEW_NOTE'=>'Create Note or Attachment',
'LNK_NEW_EMAIL'=>'Archive Email',
'LNK_CALL_LIST'=>'Calls',
'LNK_MEETING_LIST'=>'Meetings',
'LNK_TASK_LIST'=>'Tasks',
'LNK_NOTE_LIST'=>'Notes',
'LNK_EMAIL_LIST'=>'Emails',

  'LNK_VIEW_CALENDAR' => 'Today',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the meeting.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
  'LBL_INVITEE' => 'Invitees',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',
);


?>

==> sugarcrm-3.5.1.tbz: www/sugarcrm/modules/Meetings/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version
 * 1.1.3 ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * All copies of the Covered Code must include on each user interface screen:
 *    (i) the "Powered by SugarCRM" logo and
 *    (ii) the SugarCRM copyright notice
 * in the same form as they appear in the distribution.  See full license for
 * requirements.
 *
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) 2004-2005 SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Id: en_us.lang.php,v 1.45 2005/09/14 02:30:39 chris Exp $
 * Description:  Defines the English language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = array (
  'LBL_MODULE_NAME' => 'Meetings',
  'LBL_MODULE_TITLE' => 'Meetings: Home',
  'LBL_SEARCH_FORM_TITLE' => 'Meeting Search',
  'LBL_LIST_FORM_TITLE' => 'Meeting List',
  'LBL_NEW_FORM_TITLE' => 'Schedule Meeting',
  'LBL_SCHEDULING_FORM_TITLE' => 'Scheduling',
  'LBL_LIST_SUBJECT' => 'Subject',
  'LBL_LIST_CONTACT' => 'Contact',
  'LBL_LIST_RELATED_TO' => 'Related to',
  'LBL_LIST_DATE' => 'Start Date',
  'LBL_LIST_TIME' => 'Start Time',
  'LBL_LIST_CLOSE' => 'Close',
  'LBL_SUBJECT' => 'Subject:',
  'LBL_STATUS' => 'Status:',
  'LBL_LOCATION' => 'Location:',
  'LBL_DATE_TIME' => 'Start Date & Time:',
  'LBL_DATE' => 'Start Date:',
  'LBL_TIME' => 'Start Time:',
  'LBL_DURATION' => 'Duration:',
  'LBL_DURATION_HOURS' => 'Duration Hours:',
  'LBL_DURATION_MINUTES' => 'Duration Minutes:',
  'LBL_HOURS_MINS' => '(hours/minutes)',
  'LBL_CONTACT_NAME' => 'Contact:',
  'LBL_MEETING' => 'Meeting:',
  'LBL_DESCRIPTION_INFORMATION' => 'Description Information',
  'LBL_DESCRIPTION' => 'Description:',
  'LBL_COLON' => ':',
  'LBL_DEFAULT_STATUS' => 'Planned',
'LNK_NEW_CALL'=>'Schedule Call',
'LNK_NEW_MEETING'=>'Schedule Meeting',
'LNK_NEW_TASK'=>'Create Task',
'LNK_NEW_NOTE'=>'Create Note or Attachment',
'LNK_NEW_EMAIL'=>'Archive Email',
'LNK_CALL_LIST'=>'Calls',
'LNK_MEETING_LIST'=>'Meetings',
'LNK_TASK_LIST'=>'Tasks',
'LNK_NOTE_LIST'=>'Notes',
'LNK_EMAIL_LIST'=>'Emails',

  'LNK_VIEW_CALENDAR' => 'Today',
  'ERR_DELETE_RECORD' => 'A record number must be specified to delete the meeting.',
  'NTC_REMOVE_INVITEE' => 'Are you sure you want to remove this invitee from the meeting?',
  'LBL_INVITEE' => 'Invitees',
  'LNK_NEW_APPOINTMENT' => 'Create Appointment',

  'LBL_ADD_INVITEE' => 'Add Invitees',
  'LBL_NAME' => 'Name',
  'LBL_FIRST_NAME' => 'First Name',
  'LBL_LAST_NAME' => 'Last Name',
  'LBL_EMAIL' => 'Email',
  'LBL_PHONE' => 'Phone Office:',
  'LBL_REMINDER' => 'Reminder:',
  'LBL_SEND_BUTTON_TITLE'=>'Send Invites [Alt+I]',
  'LBL_SEND_BUTTON_KEY'=>'I',
  'LBL_SEND_BUTTON_LABEL'=>'Send Invites',
  'LBL_REMINDER_TIME'=>'Reminder Time',
  'LBL_MODIFIED_BY'=>'Modified by',
  'LBL_CREATED_BY'=>'Created by',
  'LBL_DATE_END'=>'Date End',
	
  'LBL_SEARCH_BUTTON'=> 'Search',
  'LBL_ADD_BUTTON'=> 'Add',
  'LBL_DEL'=> 'Del',
  'LBL_DEFAULT_SUBPANEL_TITLE' => 'Meetings',
  'LBL_LIST_STATUS'=>'Status',
  'LBL_LIST_DUE_DATE'=>'Due Date',
  'LBL_LIST_DATE_MODIFIED'=>'Date Modified',
  
  'LBL_CONTACTS_SUBPANEL_TITLE' => 'Contacts',
  'LBL_USERS_SUBPANEL_TITLE' => 'Users',
);


?>
